<?php
/**
 * Created by PhpStorm.
 * User: 思维定制
 * Date: 2019/3/4
 * Time: 15:12
 */

namespace App\Http\Controllers\Api\V1;

use App\Models\AlbumPosterModel;
use App\Services\Base\ErrorCode;
use Validator, Response,Auth;
use Illuminate\Http\Request;

class AlbumPosterController extends Controller
{

    /**
     * @api {post} /api/album_post/info 获取海报数据(info)
     * @apiDescription 获取海报数据(info)
     * @apiGroup Album_Post
     * @apiPermission 需要登录
     * @apiVersion 0.1.0
     * @apiParam {int}    [store_id]  商户id
     * @apiSuccessExample {json} Success-Response:
     * HTTP/1.1 200 OK
     * {
     *     "status": true,
     *     "status_code": 0,
     *     "message": "",
     *     "data": [
     *           'posters':'asdawd',  //海报
     *           'words':'asdawd',    //话术
     *           'introduce':'222',   //介绍
     *           'share':'xxx'        //分享图片
     *           'phone':'xxx'        //电话
     *           'username':'xxx'     //姓名
     *      ]
     * }
     * @apiErrorExample {json} Error-Response:
     * HTTP/1.1 400 Bad Request
     * {
     *     "state": false,
     *     "code": 1000,
     *     "message": "传入参数不正确",
     *     "data": null or []
     * }
     * 可能出现的错误代码：
     *    1000    CLIENT_WRONG_PARAMS             传入参数不正确
     */
    public function posterInfo(Request $request)
    {
        $userAuth = Auth('api')->user();
        if (!$userAuth) {
            return $this->error(ErrorCode::CLIENT_WRONG_PARAMS, '未登录!');
        }
        $validator = Validator::make($request->all(), [
            'store_id' => 'required',
        ], [
            'store_id.required' => '店铺信息未知',
        ]);
        if ($validator->fails()) {
            return $this->validatorError($validator->messages()->all(), ErrorCode::CLIENT_WRONG_PARAMS, '');
        }
        $info = AlbumPosterModel::where('store_id', $request->input('store_id'))->first()->toArray();
        $info['phone'] = $userAuth->phone;
        $info['username'] = $userAuth->username;
        return $this->api(compact('info'));
    }
}